
class Skins:
    ABERRANT_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_AberrationHelmet.PrimalItemSkin_AberrationHelmet'"
    ABERRANT_SWORD_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_AberrationSword.PrimalItemSkin_AberrationSword'"
    ALPHA_RAPTOR_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_Alpha.PrimalItemSkin_SummerSwimPants_Alpha'"
    ALPHA_RAPTOR_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_Alpha.PrimalItemSkin_SummerSwimShirt_Alpha'"
    ARANEO_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_Underwear_Araneo.PrimalItemSkin_FE_Underwear_Araneo'"
    ARANEO_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_SwimShirt_Araneo.PrimalItemSkin_FE_SwimShirt_Araneo'"
    ARK_TESTER_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItem_Skin_Account_GameTester.PrimalItem_Skin_Account_GameTester'"
    BASILISK_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostBasilisk.PrimalItemCostume_GhostBasilisk'"
    BIRTHDAY_SUIT_PANTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_BirthdayPants.PrimalItemSkin_BirthdayPants'"
    BIRTHDAY_SUIT_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_BirthdayShirt.PrimalItemSkin_BirthdayShirt'"
    BLUE_BALL_WINTER_BEANIE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_WinterHatD.PrimalItemSkin_WW_WinterHatD'"
    BONNET_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_BonnetHat.PrimalItemSkin_TT_BonnetHat'"
    BOW_EROS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CupidBow.PrimalItemSkin_CupidBow'"
    BRACHIOSAURUS_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemCostume_Brachiosaurus.PrimalItemCostume_Brachiosaurus'"
    BRONTO_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneSauro.PrimalItemCostume_BoneSauro'"
    BULBDOG_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostLanternPug.PrimalItemCostume_GhostLanternPug'"
    BULBDOG_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_PugMask.PrimalItemSkin_PugMask'"
    BULBDOG_PRINT_SHIRT_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Bulbdog.PrimalItemSkin_HawaiianShirt_Bulbdog'"
    BUNNY_EARS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_BunnyHat.PrimalItemSkin_BunnyHat'"
    CANDY_CANE_CLUB_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_CandyClub.PrimalItemSkin_CandyClub'"
    CAPTAINS_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CaptainsHat.PrimalItemSkin_CaptainsHat'"
    CARNO_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneCarno.PrimalItemCostume_BoneCarno'"
    CHIEFTAN_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TurkeyHat.PrimalItemSkin_TurkeyHat'"
    CHILI_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Chili.PrimalItemSkin_Chili'"
    CHOCOLATE_RABBIT_CLUB_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Club_ChocolateRabbit.PrimalItemSkin_Club_ChocolateRabbit'"
    CHRISTMAS_BOLA_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_Xmas_Bola.PrimalItemSkin_WW_Xmas_Bola'"
    CLOWN_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ClownMask.PrimalItemSkin_ClownMask'"
    CORRUPTED_AVATAR_BOOTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Gen1AvatartBoots.PrimalItemSkin_Gen1AvatartBoots'"
    CORRUPTED_AVATAR_GLOVES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Gen1AvatarGloves.PrimalItemSkin_Gen1AvatarGloves'"
    CORRUPTED_AVATAR_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Gen1AvatarHelmet.PrimalItemSkin_Gen1AvatarHelmet'"
    CORRUPTED_AVATAR_PANTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Gen1AvatarPants.PrimalItemSkin_Gen1AvatarPants'"
    CORRUPTED_AVATAR_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Gen1AvatarShirt.PrimalItemSkin_Gen1AvatarShirt'"
    CORRUPTED_BOOTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CorruptedBoots.PrimalItemSkin_CorruptedBoots'"
    CORRUPTED_CHESTPIECE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CorruptedShirt.PrimalItemSkin_CorruptedShirt'"
    CORRUPTED_GLOVES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CorruptedGloves.PrimalItemSkin_CorruptedGloves'"
    CORRUPTED_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CorruptedHelmet.PrimalItemSkin_CorruptedHelmet'"
    CORRUPTED_PANTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_CorruptedPants.PrimalItemSkin_CorruptedPants'"
    CRAB_FEST_SWIM_BOTTOM_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_CrabParty.PrimalItemSkin_SummerSwimPants_CrabParty'"
    CRAB_FEST_SWIM_TOP_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_CrabParty.PrimalItemSkin_SummerSwimShirt_CrabParty'"
    CUPID_COUTURE_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ValentinePants.PrimalItemSkin_ValentinePants'"
    CUPID_COUTURE_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ValentineShirt.PrimalItemSkin_ValentineShirt'"
    CUTE_DINO_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DinoCute.PrimalItemSkin_DinoCute'"
    DECORATIVE_RAVAGER_SADDLE_SKIN = "Blueprint'/Game/Aberration/Dinos/CaveWolf/PrimalItemArmor_CavewolfPromoSaddle.PrimalItemArmor_CavewolfPromoSaddle'"
    DILO_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DiloMask.PrimalItemSkin_DiloMask'"
    DINO_BUNNY_EARS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_DinoBunnyHat.PrimalItemSkin_DinoBunnyHat'"
    DINO_EASTER_CHICK_HAT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DinoChickHat.PrimalItemSkin_DinoChickHat'"
    DINO_EASTER_EGG_HAT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DinoEasterEggHat.PrimalItemSkin_DinoEasterEggHat'"
    DINO_GLASSES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_DinoSpecs.PrimalItemSkin_DinoSpecs'"
    DINO_MARSHMALLOW_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DinoMarshmallowHat.PrimalItemSkin_DinoMarshmallowHat'"
    DINO_ORNAMENT_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_Underwear_DinoOrnaments.PrimalItemSkin_WW_Underwear_DinoOrnaments'"
    DINO_ORNAMENT_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_SwimShirt_DinoOrnaments.PrimalItemSkin_WW_SwimShirt_DinoOrnaments'"
    DINO_PARTY_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_DinoPartyHat.PrimalItemSkin_DinoPartyHat'"
    DINO_SANTA_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DinoSantaHat.PrimalItemSkin_DinoSantaHat'"
    DINO_UNCLE_SAM_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TopHat_Summer_Dino.PrimalItemSkin_TopHat_Summer_Dino'"
    DINO_WITCH_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_DinoWitchHat.PrimalItemSkin_DinoWitchHat'"
    DIREWOLF_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostDirewolf.PrimalItemCostume_GhostDirewolf'"
    DODO_PIE_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimPants_DodoPie.PrimalItemSkin_TT_SwimPants_DodoPie'"
    DODO_PIE_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimShirt_DodoPie.PrimalItemSkin_TT_SwimShirt_DodoPie'"
    DODOREX_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DodorexMask.PrimalItemSkin_DodorexMask'"
    DODOREX_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SwimPants_Dodo.PrimalItemSkin_SwimPants_Dodo'"
    DODOREX_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SwimShirt_Dodo.PrimalItemSkin_SwimShirt_Dodo'"
    DODOREX_PRINT_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Dodo.PrimalItemSkin_HawaiianShirt_Dodo'"
    DODOWYVERN_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_DodowyvernHat.PrimalItemSkin_DodowyvernHat'"
    E4_REMOTE_EGGSPLOSIVES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_EasterBasket_C4.PrimalItemSkin_EasterBasket_C4'"
    EASTER_CHICK_HAT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_EasterChick.PrimalItemSkin_EasterChick'"
    EASTER_EGG_HAT = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_EasterEggHat.PrimalItemSkin_EasterEggHat'"
    EASTER_EGGHEAD_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_EggNestHat.PrimalItemSkin_EggNestHat'"
    FAN_BALLCAP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItem_Skin_Account_WildcardAdmin.PrimalItem_Skin_Account_WildcardAdmin'"
    FEDERATION_EXO_BOOTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TekBoots_V2.PrimalItemSkin_TekBoots_V2'"
    FEDERATION_EXO_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TekHelmet_V2.PrimalItemSkin_TekHelmet_V2'"
    FEDERATION_EXO_CHESTPIECE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TekShirt_V2.PrimalItemSkin_TekShirt_V2'"
    FEDERATION_EXO_GLOVES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TekGloves_V2.PrimalItemSkin_TekGloves_V2'"
    FEDERATION_EXO_LEGGINGS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TekPants_V2.PrimalItemSkin_TekPants_V2'"
    FELT_REINDEER_ANTLERS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_ReindeerAntlersHat.PrimalItemSkin_WW_ReindeerAntlersHat'"
    FIREWORKS_FLAREGUN_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_FlaregunFireworks.PrimalItemSkin_FlaregunFireworks'"
    FIREWORKS_ROCKET_LAUNCHER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_RocketLauncherFireworks.PrimalItemSkin_RocketLauncherFireworks'"
    FISH_BITE_SWIM_BOTTOM_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_FishBite.PrimalItemSkin_SummerSwimPants_FishBite'"
    FISH_BITE_SWIM_TOP_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_FishBite.PrimalItemSkin_SummerSwimShirt_FishBite'"
    FLORAL_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_Flowers.PrimalItemSkin_SummerSwimPants_Flowers'"
    FLORAL_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_Flowers.PrimalItemSkin_SummerSwimShirt_Flowers'"
    FLYING_DISC_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Boomerang_Frisbee.PrimalItemSkin_Boomerang_Frisbee'"
    GASBAGS_PRINT_SHIRT_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Gasbags.PrimalItemSkin_HawaiianShirt_Gasbags'"
    GIGA_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicGigant.PrimalItemCostume_BionicGigant'"
    GIGA_POOP_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_Carno.PrimalItemSkin_SummerSwimPants_Carno'"
    GIGA_POOP_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_Carno.PrimalItemSkin_SummerSwimShirt_Carno'"
    GIGANOTOSAURUS_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneGigant.PrimalItemCostume_BoneGigant'"
    GLIDER_SUIT = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Armor/PrimalItemArmor_Glider.PrimalItemArmor_Glider'"
    GRAY_BALL_WINTER_BEANIE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_WinterHatB.PrimalItemSkin_WW_WinterHatB'"
    GREEN_BALL_WINTER_BEANIE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_WinterHatF.PrimalItemSkin_WW_WinterHatF'"
    GRILLING_SPATULA_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Club_BBQSpatula.PrimalItemSkin_Club_BBQSpatula'"
    HALO_HEADBAND_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ValentineHaloHat.PrimalItemSkin_ValentineHaloHat'"
    HEADLESS_COSTUME_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_HeadlessHat.PrimalItemSkin_FE_HeadlessHat'"
    HEART_SHAPED_SHIELD_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Vday_Shield.PrimalItemSkin_Vday_Shield'"
    HEART_SHAPED_SUNGLASSES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SunGlasses_Vday.PrimalItemSkin_SunGlasses_Vday'"
    HOCKEY_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_ScaryFaceMask.PrimalItemSkin_FE_ScaryFaceMask'"
    HOMODEUS_BOOTS_SKIN = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Skin/PrimalItemSkin_HomoDeusBoots.PrimalItemSkin_HomoDeusBoots'"
    HOMODEUS_GLOVES_SKIN = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Skin/PrimalItemSkin_HomoDeusGloves.PrimalItemSkin_HomoDeusGloves'"
    HOMODEUS_HELMET_SKIN = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Skin/PrimalItemSkin_HomoDeusHelmet.PrimalItemSkin_HomoDeusHelmet'"
    HOMODEUS_PANTS_SKIN = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Skin/PrimalItemSkin_HomoDeusPants.PrimalItemSkin_HomoDeusPants'"
    HOMODEUS_SHIRT_SKIN = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Skin/PrimalItemSkin_HomoDeusShirt.PrimalItemSkin_HomoDeusShirt'"
    HUNTER_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemArmor_HideHelmetAlt.PrimalItemArmor_HideHelmetAlt'"
    ICE_POP_PRINT_SHIRT_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Island.PrimalItemSkin_HawaiianShirt_Island'"
    ICHTHY_ISLES_SWIM_BOTTOM_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_IslandRetreat.PrimalItemSkin_SummerSwimPants_IslandRetreat'"
    ICHTHY_ISLES_SWIM_TOP_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_IslandRetreat.PrimalItemSkin_SummerSwimShirt_IslandRetreat'"
    JACK_O_LANTERN_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_Underwear_Pumpkin.PrimalItemSkin_FE_Underwear_Pumpkin'"
    JACK_O_LANTERN_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_SwimShirt_Pumpkin.PrimalItemSkin_FE_SwimShirt_Pumpkin'"
    JACK_O_LANTERN_PRINT_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Pumpkin.PrimalItemSkin_HawaiianShirt_Pumpkin'"
    JERBOA_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneJerboa.PrimalItemCostume_BoneJerboa'"
    JERBOA_WREATH_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_Underwear_JerboaWreath.PrimalItemSkin_WW_Underwear_JerboaWreath'"
    JERBOA_WREATH_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_SwimShirt_JerboaWreath.PrimalItemSkin_WW_SwimShirt_JerboaWreath'"
    LOVE_SHACKLES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Vday_Handcuffs.PrimalItemSkin_Vday_Handcuffs'"
    MANTICORE_BOOTS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticoreBoots.PrimalItemSkin_ManticoreBoots'"
    MANTICORE_CHESTPIECE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticoreShirt.PrimalItemSkin_ManticoreShirt'"
    MANTICORE_GAUNTLETS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticoreGloves.PrimalItemSkin_ManticoreGloves'"
    MANTICORE_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticoreHelmet.PrimalItemSkin_ManticoreHelmet'"
    MANTICORE_LEGGINGS_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticorePants.PrimalItemSkin_ManticorePants'"
    MANTICORE_SHIELD_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ManticoreShield.PrimalItemSkin_ManticoreShield'"
    MANTIS_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostMantis.PrimalItemCostume_GhostMantis'"
    MARSHMALLOW_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_MarshmallowHat.PrimalItemSkin_MarshmallowHat'"
    MASTER_CONTROLLER_HELMET_SKIN = "Blueprint'/Game/Genesis/CoreBlueprints/Items/PrimalItemSkin_MasterControllerHelmet.PrimalItemSkin_MasterControllerHelmet'"
    MEAT_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimPants_Meat.PrimalItemSkin_TT_SwimPants_Meat'"
    MEAT_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimShirt_Meat.PrimalItemSkin_TT_SwimShirt_Meat'"
    MEGALOCEROS_REINDEER_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_ReindeerStag.PrimalItemCostume_ReindeerStag'"
    MINI_HLNA_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_MiniHLNA.PrimalItemSkin_MiniHLNA'"
    MOSASAURUS_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicMosa.PrimalItemCostume_BionicMosa'"
    MURDER_TURKEY_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SwimPants_MurderTurkey.PrimalItemSkin_SwimPants_MurderTurkey'"
    MURDER_TURKEY_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SwimShirt_MurderTurkey.PrimalItemSkin_SwimShirt_MurderTurkey'"
    MURDER_TURKEY_PRINT_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_MurderTurkey.PrimalItemSkin_HawaiianShirt_MurderTurkey'"
    NERDRY_GLASSES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_Glasses.PrimalItemSkin_Glasses'"
    NOGLIN_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_Underwear_Noglin.PrimalItemSkin_WW_Underwear_Noglin'"
    NOGLIN_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_SwimShirt_Noglin.PrimalItemSkin_WW_SwimShirt_Noglin'"
    NUTCRACKER_SLINGSHOT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_WW_Nutcracker_Slingshot.PrimalItemSkin_WW_Nutcracker_Slingshot'"
    ONYC_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_Underwear_Onyc.PrimalItemSkin_FE_Underwear_Onyc'"
    ONYC_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_SwimShirt_Onyc.PrimalItemSkin_FE_SwimShirt_Onyc'"
    OTTER_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_OtterMask.PrimalItemSkin_OtterMask'"
    PARASAUR_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicParasaur.PrimalItemCostume_BionicParasaur'"
    PARASAUR_STYLISH_SADDLE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ParaSaddle_Launch.PrimalItemArmor_ParaSaddle_Launch'"
    PARTY_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_PartyHat.PrimalItemSkin_PartyHat'"
    PILGRIM_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_PilgrimHat.PrimalItemSkin_TT_PilgrimHat'"
    PITCHFORK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_Pike_Pitchfork.PrimalItemSkin_TT_Pike_Pitchfork'"
    POGLIN_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_PoglinHat.PrimalItemSkin_PoglinHat'"
    PROCOPTODON_BUNNY_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_ProcopBunny.PrimalItemCostume_ProcopBunny'"
    PURPLE_BALL_WINTER_BEANIE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_WW_WinterHatC.PrimalItemSkin_WW_WinterHatC'"
    PURPLE_BALL_WINTER_BEANIE_SKIN_WINTER_WONDERLAND_5 = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_WinterHatE.PrimalItemSkin_WW_WinterHatE'"
    QUETZAL_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicQuetzal.PrimalItemCostume_BionicQuetzal'"
    RAPTOR_ARK_THE_ANIMATED_SERIES_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_AnimeRaptor.PrimalItemCostume_AnimeRaptor'"
    RAPTOR_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicRaptor.PrimalItemCostume_BionicRaptor'"
    QUETZALCOATLUS_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneQuetz.PrimalItemCostume_BoneQuetz'"
    RAPTOR_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneRaptor.PrimalItemCostume_BoneRaptor'"
    REAPER_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostReaper.PrimalItemCostume_GhostReaper'"
    REAPER_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ReaperHelmet.PrimalItemSkin_ReaperHelmet'"
    REAPER_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_Underwear_Reaper.PrimalItemSkin_FE_Underwear_Reaper'"
    REAPER_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_SwimShirt_Reaper.PrimalItemSkin_FE_SwimShirt_Reaper'"
    REAPER_PRINT_SHIRT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_Reaper.PrimalItemSkin_HawaiianShirt_Reaper'"
    RED_BALL_WINTER_BEANIE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_WW_WinterHatA.PrimalItemSkin_WW_WinterHatA'"
    REX_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicRex.PrimalItemCostume_BionicRex'"
    REX_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneRex.PrimalItemCostume_BoneRex'"
    REX_BONE_HELMET = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_BoneHelmet.PrimalItemSkin_BoneHelmet'"
    REX_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostRex.PrimalItemCostume_GhostRex'"
    REX_STOMPED_GLASSES_SADDLE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_RexSaddle_StompedGlasses.PrimalItemArmor_RexSaddle_StompedGlasses'"
    SAFARI_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ExplorerHat.PrimalItemSkin_ExplorerHat'"
    SANTA_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SantaHat.PrimalItemSkin_SantaHat'"
    SANTIAGOS_AXE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItemSkin_Hatchet_Santiago.PrimalItemSkin_Hatchet_Santiago'"
    SANTIAGOS_SPEAR_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItemSkin_Spear_Santiago.PrimalItemSkin_Spear_Santiago'"
    SCARY_PUMPKIN_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_PumpkinHat.PrimalItemSkin_FE_PumpkinHat'"
    SCARY_SKULL_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_ScarySkull.PrimalItemSkin_ScarySkull'"
    SCORCHED_SPIKE_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_ScorchedSpear.PrimalItemSkin_ScorchedSpear'"
    SCORCHED_SWORD_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_ScorchedSword.PrimalItemSkin_ScorchedSword'"
    SCORCHED_TORCH_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_TorchScorched.PrimalItemSkin_TorchScorched'"
    SEA_LIFE_PRINT_SHIRT_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_HawaiianShirt_SeaStuff.PrimalItemSkin_HawaiianShirt_SeaStuff'"
    SNOW_OWL_GHOST_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_GhostOwl.PrimalItemCostume_GhostOwl'"
    STEGO_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneStego.PrimalItemCostume_BoneStego'"
    STEGOSAURUS_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicStego.PrimalItemCostume_BionicStego'"
    STYGIMOLOCH_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemCostume_Stygimoloch.PrimalItemCostume_Stygimoloch'"
    STYRACOSAURUS_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemCostume_Styracosaurus.PrimalItemCostume_Styracosaurus'"
    SUNGLASSES_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SunGlasses.PrimalItemSkin_SunGlasses'"
    SWEET_SPEAR_CARROT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Weapons/PrimalItemSkin_Spear_Carrot.PrimalItemSkin_Spear_Carrot'"
    T_REX_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimPants_Arthro.PrimalItemSkin_SummerSwimPants_Arthro'"
    T_REX_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_SummerSwimShirt_Arthro.PrimalItemSkin_SummerSwimShirt_Arthro'"
    TEDDY_BEAR_GRENADES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_VDay_Grenade_ValentineBear.PrimalItemSkin_VDay_Grenade_ValentineBear'"
    THORNY_DRAGON_VAGABOND_SADDLE_SKIN = "Blueprint'/Game/ScorchedEarth/Dinos/SpineyLizard/PrimalItemArmor_SpineyLizardPromoSaddle.PrimalItemArmor_SpineyLizardPromoSaddle'"
    TOP_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TopHat.PrimalItemSkin_TopHat'"
    TORCH_SPARKLER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_TorchSparkler.PrimalItemSkin_TorchSparkler'"
    TRICERATOPS_BIONIC_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BionicTrike.PrimalItemCostume_BionicTrike'"
    TRIKE_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneTrike.PrimalItemCostume_BoneTrike'"
    TRIKE_BONE_HELMET_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItemSkin_TrikeSkullHelmet.PrimalItemSkin_TrikeSkullHelmet'"
    TURKEY_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_ActualTurkeyHat.PrimalItemSkin_TT_ActualTurkeyHat'"
    TURKEY_LEG_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_Club_TurkeyLeg.PrimalItemSkin_TT_Club_TurkeyLeg'"
    TURKEY_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimPants_TurkeyBerry.PrimalItemSkin_TT_SwimPants_TurkeyBerry'"
    TURKEY_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TT_SwimShirt_TurkeyBerry.PrimalItemSkin_TT_SwimShirt_TurkeyBerry'"
    UGLY_BRONTO_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweaterBronto.PrimalItemSkin_WW_XmasSweaterBronto'"
    UGLY_BULBDOG_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweater_Bulbdog.PrimalItemSkin_WW_XmasSweater_Bulbdog'"
    UGLY_CARNO_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweaterCarno.PrimalItemSkin_WW_XmasSweaterCarno'"
    UGLY_CAROLING_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweater_Carolers.PrimalItemSkin_WW_XmasSweater_Carolers'"
    UGLY_CHIBI_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweaterChibi.PrimalItemSkin_WW_XmasSweaterChibi'"
    UGLY_CORNUCOPIA_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Sweater_Cornucopia.PrimalItemSkin_Sweater_Cornucopia'"
    UGLY_T_REX_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_XmasSweater_Rex.PrimalItemSkin_WW_XmasSweater_Rex'"
    UGLY_TRIKE_SWEATER_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Sweater_Trike.PrimalItemSkin_Sweater_Trike'"
    UNCLE_SAM_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_TopHat_Summer.PrimalItemSkin_TopHat_Summer'"
    VAMPIRE_DODO_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_Underwear_VampireDodo.PrimalItemSkin_FE_Underwear_VampireDodo'"
    VAMPIRE_DODO_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_FE_SwimShirt_VampireDodo.PrimalItemSkin_FE_SwimShirt_VampireDodo'"
    VAMPIRE_EYES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_VampireEyes.PrimalItemSkin_VampireEyes'"
    WATER_SOAKER_SKIN = "Blueprint'/Game/ PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_Flamethrower_SuperSoaker.PrimalItemSkin_Flamethrower_SuperSoaker'"
    WEREWOLF_MASK_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WerewolfHat.PrimalItemSkin_WerewolfHat'"
    WITCH_HAT_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WitchHat.PrimalItemSkin_WitchHat'"
    WIZARD_BALLCAP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Leather/PrimalItem_Skin_Account_DevKitMaster.PrimalItem_Skin_Account_DevKitMaster'"
    WYVERN_BONE_COSTUME = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemCostume_BoneWyvern.PrimalItemCostume_BoneWyvern'"
    WYVERN_GLOVES_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WyvernGloves.PrimalItemSkin_WyvernGloves'"
    YETI_SWIM_BOTTOM_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_Underwear_Yeti.PrimalItemSkin_WW_Underwear_Yeti'"
    YETI_SWIM_TOP_SKIN = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Skin/PrimalItemSkin_WW_SwimShirt_Yeti.PrimalItemSkin_WW_SwimShirt_Yeti'"
    ZIP_LINE_MOTOR_ATTACHMENT_SKIN = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Armor/PrimalItemArmor_ZiplineMotor.PrimalItemArmor_ZiplineMotor'"



class Eggs:
    URUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Allo.PrimalItemConsumable_Egg_Allo'"
    ANKYLO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Ankylo.PrimalItemConsumable_Egg_Ankylo'"
    ARANEO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Spider.PrimalItemConsumable_Egg_Spider'"
    ARCHAEOPTERYX_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Archa.PrimalItemConsumable_Egg_Archa'"
    ARGENTAVIS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Argent.PrimalItemConsumable_Egg_Argent'"
    ARTHROPLUERA_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Arthro.PrimalItemConsumable_Egg_Arthro'"
    BARYONYX_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Baryonyx.PrimalItemConsumable_Egg_Baryonyx'"
    BASILISK_EGG = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_Basilisk.PrimalItemConsumable_Egg_Basilisk'"
    BLOOD_CRYSTAL_WYVERN_EGG = "Blueprint'/Game/PrimalEarth/Dinos/CrystalWyvern/Eggs/PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_Bloodfall.PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_Bloodfall'"
    BLOODSTALKER_EGG = "Blueprint'/Game/Genesis/Dinos/BogSpider/PrimalItemConsumable_Egg_BogSpider.PrimalItemConsumable_Egg_BogSpider'"
    BRONTO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Bronto.PrimalItemConsumable_Egg_Bronto'"
    CAMELSAURUS_EGG = "Blueprint'/Game/ScorchedEarth/Dinos/Camelsaurus/PrimalItemConsumable_Egg_Camelsaurus.PrimalItemConsumable_Egg_Camelsaurus'"
    CARNO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Carno.PrimalItemConsumable_Egg_Carno'"
    COMPY_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Compy.PrimalItemConsumable_Egg_Compy'"
    CRYSTAL_WYVERN_EGG = "Blueprint'/Game/PrimalEarth/Dinos/CrystalWyvern/Eggs/PrimalItemConsumable_Egg_CrystalWyvern.PrimalItemConsumable_Egg_CrystalWyvern'"
    DEINONYCHUS_EGG = "Blueprint'/Game/Valguero/Dinos/Deinonychus/PrimalItemConsumable_Egg_Deinonychus_Fertilized.PrimalItemConsumable_Egg_Deinonychus_Fertilized'"
    DILO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Dilo.PrimalItemConsumable_Egg_Dilo'"
    DIMETRODON_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Dimetrodon.PrimalItemConsumable_Egg_Dimetrodon'"
    DIMORPH_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Dimorph.PrimalItemConsumable_Egg_Dimorph'"
    DIPLO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Diplo.PrimalItemConsumable_Egg_Diplo'"
    DODO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Dodo.PrimalItemConsumable_Egg_Dodo'"
    EMBER_CRYSTAL_WYVERN_EGG = "Blueprint'/Game/PrimalEarth/Dinos/CrystalWyvern/Eggs/PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_Ember.PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_Ember'"
    FEATHERLIGHT_EGG = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_LanternBird.PrimalItemConsumable_Egg_LanternBird'"
    FISH_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_UnderwaterEgg.PrimalItemConsumable_UnderwaterEgg'"
    GALLIMIMUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Galli.PrimalItemConsumable_Egg_Galli'"
    GIGANOTOSAURUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Gigant.PrimalItemConsumable_Egg_Gigant'"
    GLOWTAIL_EGG = "Blueprint'/Game/Aberration/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_LanternLizard.PrimalItemConsumable_Egg_LanternLizard'"
    GOLDEN_HESPERORNIS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Hesperonis_Golden.PrimalItemConsumable_Egg_Hesperonis_Golden'"
    HESPERORNIS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Hesperonis.PrimalItemConsumable_Egg_Hesperonis'"
    ICHTHYORNIS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Ichthyornis.PrimalItemConsumable_Egg_Ichthyornis'"
    IGUANODON_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Iguanodon.PrimalItemConsumable_Egg_Iguanodon'"
    KAIRUKU_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Kairuku.PrimalItemConsumable_Egg_Kairuku'"
    KAPROSUCHUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Kaprosuchus.PrimalItemConsumable_Egg_Kaprosuchus'"
    KENTRO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Kentro.PrimalItemConsumable_Egg_Kentro'"
    LYSTRO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Lystro.PrimalItemConsumable_Egg_Lystro'"
    MAGMASAUR_EGG = "Blueprint'/Game/Genesis/Dinos/Cherufe/PrimalItemConsumable_Egg_Cherufe.PrimalItemConsumable_Egg_Cherufe'"
    MANTIS_EGG = "Blueprint'/Game/ScorchedEarth/Dinos/Mantis/PrimalItemConsumable_Egg_Mantis.PrimalItemConsumable_Egg_Mantis'"
    MEGACHELON_EGG = "Blueprint'/Game/Genesis/Dinos/GiantTurtle/PrimalItemConsumable_Egg_GiantTurtle.PrimalItemConsumable_Egg_GiantTurtle'"
    MEGALANIA_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Megalania.PrimalItemConsumable_Egg_Megalania'"
    MEGALOSAURUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Megalosaurus.PrimalItemConsumable_Egg_Megalosaurus'"
    MICRORAPTOR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_MicroRaptor.PrimalItemConsumable_Egg_MicroRaptor'"
    MOSCHOPS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Moschops.PrimalItemConsumable_Egg_Moschops'"
    MOTH_EGG = "Blueprint'/Game/ScorchedEarth/Dinos/Moth/PrimalItemConsumable_Egg_Moth.PrimalItemConsumable_Egg_Moth'"
    OVIRAPTOR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Oviraptor.PrimalItemConsumable_Egg_Oviraptor'"
    PACHYCEPHALOSAURUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Pachy.PrimalItemConsumable_Egg_Pachy'"
    PACHYRHINO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Pachyrhino.PrimalItemConsumable_Egg_Pachyrhino'"
    PARASAUR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Para.PrimalItemConsumable_Egg_Para'"
    PEGOMASTAX_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Pegomastax.PrimalItemConsumable_Egg_Pegomastax'"
    PELAGORNIS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Pela.PrimalItemConsumable_Egg_Pela'"
    PTERANODON_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Ptero.PrimalItemConsumable_Egg_Ptero'"
    PULMONOSCORPIUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Scorpion.PrimalItemConsumable_Egg_Scorpion'"
    QUETZAL_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Quetz.PrimalItemConsumable_Egg_Quetz'"
    RAPTOR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Raptor.PrimalItemConsumable_Egg_Raptor'"
    REX_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Rex.PrimalItemConsumable_Egg_Rex'"
    ROCK_DRAKE_EGG = "Blueprint'/Game/Aberration/Dinos/RockDrake/PrimalItemConsumable_Egg_RockDrake_Fertilized.PrimalItemConsumable_Egg_RockDrake_Fertilized'"
    SARCO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Sarco.PrimalItemConsumable_Egg_Sarco'"
    SNOW_OWL_EGG = "Blueprint'/Game/Extinction/Dinos/Owl/PrimalItemConsumable_Egg_Owl.PrimalItemConsumable_Egg_Owl'"
    SPINO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Spino.PrimalItemConsumable_Egg_Spino'"
    STEGO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Stego.PrimalItemConsumable_Egg_Stego'"
    TAPEJARA_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Tapejara.PrimalItemConsumable_Egg_Tapejara'"
    TEK_PARASAUR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Para_Bionic.PrimalItemConsumable_Egg_Para_Bionic'"
    TEK_QUETZAL_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Quetz_Bionic.PrimalItemConsumable_Egg_Quetz_Bionic'"
    TEK_RAPTOR_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Raptor_Bionic.PrimalItemConsumable_Egg_Raptor_Bionic'"
    TEK_REX_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Rex_Bionic.PrimalItemConsumable_Egg_Rex_Bionic'"
    TEK_STEGO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Stego_Bionic.PrimalItemConsumable_Egg_Stego_Bionic'"
    TEK_TRIKE_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Trike_Bionic.PrimalItemConsumable_Egg_Trike_Bionic'"
    TERROR_BIRD_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_TerrorBird.PrimalItemConsumable_Egg_Terrorbird'"
    THERIZINO_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Therizino.PrimalItemConsumable_Egg_Therizino'"
    THORNY_DRAGON_EGG = "Blueprint'/Game/ScorchedEarth/Dinos/SpineyLizard/PrimalItemConsumable_Egg_SpineyLizard.PrimalItemConsumable_Egg_SpineyLizard'"
    TITANOBOA_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Boa.PrimalItemConsumable_Egg_Boa'"
    TRIKE_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Trike.PrimalItemConsumable_Egg_Trike'"
    TROODON_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Troodon.PrimalItemConsumable_Egg_Troodon'"
    TROPICAL_CRYSTAL_WYVERN_EGG = "Blueprint'/Game/PrimalEarth/Dinos/CrystalWyvern/Eggs/PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_WS.PrimalItemConsumable_Egg_CrystalWyvern_Fertilized_WS'"
    TROPEOGNATHUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Tropeognathus.PrimalItemConsumable_Egg_Tropeognathus'"
    TURTLE_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Turtle.PrimalItemConsumable_Egg_Turtle'"
    VELONASAUR_EGG = "Blueprint'/Game/Extinction/Dinos/Spindles/PrimalItemConsumable_Egg_Spindles.PrimalItemConsumable_Egg_Spindles'"
    VULTURE_EGG = "Blueprint'/Game/ScorchedEarth/Dinos/Vulture/PrimalItemConsumable_Egg_Vulture.PrimalItemConsumable_Egg_Vulture'"
    WYVERN_EGG_FIRE = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Wyvern_Fertilized_Fire.PrimalItemConsumable_Egg_Wyvern_Fertilized_Fire'"
    WYVERN_EGG_LIGHTNING = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Wyvern_Fertilized_Lightning.PrimalItemConsumable_Egg_Wyvern_Fertilized_Lightning'"
    WYVERN_EGG_POISON = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Wyvern_Fertilized_Poison.PrimalItemConsumable_Egg_Wyvern_Fertilized_Poison'"
    YUTYRANNUS_EGG = "Blueprint'/Game/PrimalEarth/Test/PrimalItemConsumable_Egg_Yuty.PrimalItemConsumable_Egg_Yuty'"
    EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg.PrimalItemConsumable_Egg'"
    LARGE_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_Large.PrimalItemConsumable_Egg_Large'"
    MEDIUM_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_Medium.PrimalItemConsumable_Egg_Medium'"
    SMALL_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_Small.PrimalItemConsumable_Egg_Small'"
    SPECIAL_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_Special.PrimalItemConsumable_Egg_Special'"
    EXTRA_LARGE_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_XtraLarge.PrimalItemConsumable_Egg_XtraLarge'"
    EXTRA_SMALL_EGG = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Consumables/PrimalItemConsumable_Egg_XSmall.PrimalItemConsumable_Egg_XSmall'"


import json
from arklibrary.admin import Admin
from time import sleep


def game_driver_config():
    with open("config.json", 'r') as r:
        return json.load(r)["gamedriver"]


def order_to_products(order: Order):
    assert order is not None, "An order can not be None."
    user = User.find(xuid=order.xuid)
    account = Account.find(xuid=order.xuid)
    product_orders = {"gamertag": user.gamertag, "player_id": account.player_id, "orders": []}
    for order_item in order:
        product_id = order_item.product_id
        quantity = order_item.quantity
        product_orders["orders"].append({"product": Product.find(id=product_id), "quantity": quantity})
    return product_orders


def iter_orders():
    orders = Order.all_new()
    for order in orders:
        order_prod = order_to_products(order)
        yield order_prod
        gamertag = order_prod["gamertag"]
        print('\033[92m' + f"[{gamertag}]: Finished order." + '\033[0m')
        order.process()


def get_admin():
    config = game_driver_config()
    admin = Admin(password=config["admin_password"])
    admin.enable_admin().execute()
    sleep(1)
    return admin


def run(admin: Admin=None):
    if admin is None:
        admin = get_admin()
    while True:
        try:
            for i, order in enumerate(iter_orders()):
                print('\033[34m' + f"[{order['gamertag']}]: Starting order." + '\033[0m')
                for order_item in order["orders"]:
                    product = order_item["product"]
                    quantity = order_item["quantity"]
                    print('\033[93m' + f"[{order['gamertag']}]: product={product} quantity={quantity}" + '\033[0m')
                    admin.give_items_to_player(order["player_id"], [product.blueprint[1:-1]] * quantity, quantity=product.stack_size)
                if i % 5 == 0:
                    admin.execute()
            admin.execute()
            sleep(5)
        except Exception as e:
            print('\033[31m' + f"[FAILED]: {e}" + '\033[0m')

if __name__ == "__main__":
    pass


default = [-366253, 53155, -48967]

from gamedriver import Admin
from gamedriver import Island
from time import sleep
from random import choices
import numpy as np
from pathlib import Path


default = [358401, 24641, -3101]

import json


def save_current_coordinates(map, name, num_drops, coords):
    """ Stores the coordinates into file with a name
    :param name: str, name for the coordinates
    """
    data = {"center": {}, "gen1": {}, "gen2": {}, "island": {},
            "scortched": {}, "ragnarok": {}, "extinction": {}, "aberration": {}}
    if map not in data:
        raise NotImplemented("'{}' isn't part of the map list: {}".format(map, data.keys()))
    file_path = Path.cwd() / Path('logs/saved_coordinates.json')
    if file_path.exists():
        with open(file_path, 'r') as r:
            data = json.load(r)
    if str(num_drops) not in data[map][name]:
        data[map][name][str(num_drops)] = coords
    with open(file_path, "w") as w:
        json.dump(data, w)


def generate_obelisk_drop_coords(admin, map: str, color: str, number_of_drops: int):
    with open("logs/saved_coordinates.json", 'r') as r:
        data = json.load(r)
    coords = None
    name = None
    if color.lower() == 'blue':
        coords = data[map]['blue_obelisk']
        name = 'blue_obelisk_drops'
    elif color.lower() == 'green':
        coords = data[map]['green_obelisk']
        name = 'green_obelisk_drops'
    elif color.lower() == 'red':
        coords = data[map]['red_obelisk']
        name = 'red_obelisk_drops'
    x, y, z, _, _ = coords.values()
    circumference_coords = obelisk_circle_coords([x, y, z], spokes=number_of_drops)
    coordinates = []
    finished = False
    while not finished:
        try:
            coordinates.clear()
            for i, ccc in enumerate(circumference_coords):
                admin.teleport_xyz(*ccc).execute()
                sleep(8)
                admin.driver.copy_coords()
                new_ccc_str = admin.driver.app.get_from_clipboard()
                coordinates.append([float(c) for c in new_ccc_str.split()][:3])
                if len(coordinates) == number_of_drops:
                    finished = True
                elif i + 1 != len(coordinates):
                    break
        except Exception:
            pass
        except KeyboardInterrupt:
            finished = True
    save_current_coordinates(map, name, number_of_drops, coordinates)


def obelisk_circle_coords(obelisk_center_coord, spokes=10):
    x_center, y_center, _ = obelisk_center_coord
    radius = 1763.2620338452252
    offsets = np.linspace(0, 360, spokes)
    coords = []
    for offset in offsets:
        x = radius * np.cos(offset)
        y = radius * np.sin(offset)
        coords.append((x_center + x, y + y_center, 0))
    return coords


def drop_the_supplies(admin, map, quantity=8, quality=0, only=False):
    drops = [
        Island.WHITE_BEACON,
        Island.WHITE_BEACON_DOUBLE_ITEMS,
        Island.GREEN_BEACON,
        Island.GREEN_BEACON_DOUBLE_ITEMS,
        Island.BLUE_BEACON,
        Island.BLUE_BEACON_DOUBLE_ITEMS,
        Island.PURPLE_BEACON,
        Island.PURPLE_BEACON_DOUBLE_ITEMS,
        Island.YELLOW_BEACON,
        Island.YELLOW_BEACON_DOUBLE_ITEMS,
        Island.RED_BEACON,
        Island.RED_BEACON_DOUBLE_ITEMS
    ][quality:]

    with open("gamedriver/saved_coordinates.json", 'r') as r:
        data = json.load(r)
    red = data[map]['red_obelisk_drops'][str(quantity)]
    green = data[map]['green_obelisk_drops'][str(quantity)]
    blue = data[map]['blue_obelisk_drops'][str(quantity)]

    if only:
        for ob_coords in [red, green, blue]:
            for coords in ob_coords:
                x, y, z = coords
                admin.teleport_xyz(x, y, z)
                admin.spawn_beacon(drops[0])
    else:
        weights = (100, 90, 80, 70, 60, 50, 30, 25, 20, 15, 10, 5)[quality:]
        for ob_coords in [red, green, blue]:
            shuffled_drops = choices(drops, weights=weights, k=len(ob_coords))
            for pair in zip(ob_coords, shuffled_drops):
                coords, drop = pair
                x, y, z = coords
                admin.teleport_xyz(x, y, z)
                admin.spawn_beacon(drop)
    admin.teleport_xyz(*default)
    admin.execute()


def event_supply_drops(admin, map, quantity=4, quality=4):
    if quality < 4:
        message = "Gamma Supply Drop: Event in {} seconds. Random drops will spawn at every obelisks. PVP is allowed."
    if 4 <= quality < 8:
        message = "Beta Supply Drop: Event in {} seconds. Random drops will spawn at every obelisks. PVP is allowed."
    if 8 <= quality:
        message = "Alpha supply: drop Event in {} seconds. Random drops will spawn at every obelisks. PVP is allowed."
    admin.broadcast(message.format(60))
    admin.execute()
    sleep(30)
    admin.broadcast(message.format(30))
    admin.execute()
    sleep(20)
    admin.broadcast(message.format(5))
    admin.execute()

    drop_the_supplies(admin, map, quantity, quality)


if __name__ == '__main__':
    pass


from arklibrary.data_structures import Stream
from arklibrary.lib import Ini, pathify
from arklibrary import blueprints
from arklibrary.tools import get_list, Host, set_hosts, get_info
from arklibrary.admin import Admin, Bundle


__all__ = ['Stream', 'Ini', 'blueprints', 'pathify', 'Host', 'set_hosts', 'get_info', 'get_list']



class Colorize:
    def __init__(self, dino, region_1=0, region_2=0, region_3=0, region_4=0, region_5=0, region_6=0):
        self.dino = dino
        self.region_1 = region_1
        self.region_2 = region_2
        self.region_3 = region_3
        self.region_4 = region_4
        self.region_5 = region_5
        self.region_6 = region_6

    def __str__(self):
        return "{} {} {} {} {} {}".format(self.region_1, self.region_2, self.region_3, self.region_4,
                                          self.region_5, self.region_6)


class ColorID:
    RED_ID = "1"
    BLUE_ID = "2"
    GREEN_ID = "3"
    YELLOW_ID = "4"
    CYAN_ID = "5"
    MAGENTA_ID = "6"
    LIGHT_GREEN_ID = "7"
    LIGHT_GREY_ID = "8"
    LIGHT_BROWN_ID = "9"
    LIGHT_ORANGE_ID = "10"
    LIGHT_YELLOW_ID = "11"
    LIGHT_RED_ID = "12"
    DARK_GREY_ID = "13"
    BLACK_ID = "14"
    BROWN_ID = "15"
    DARK_GREEN_ID = "16"
    DARK_RED_ID = "17"
    WHITE_ID = "18"
    DINO_LIGHT_RED_ID = "19"
    DINO_DARK_RED_ID = "20"
    DINO_LIGHT_ORANGE_ID = "21"
    DINO_DARK_ORANGE_ID = "22"
    DINO_LIGHT_YELLOW_ID = "23"
    DINO_DARK_YELLOW_ID = "24"
    DINO_LIGHT_GREEN_ID = "25"
    DINO_MEDIUM_GREEN_ID = "26"
    DINO_DARK_GREEN_ID = "27"
    DINO_LIGHT_BLUE_ID = "28"
    DINO_DARK_BLUE_ID = "29"
    DINO_LIGHT_PURPLE_ID = "30"
    DINO_DARK_PURPLE_ID = "31"
    DINO_LIGHT_BROWN_ID = "32"
    DINO_MEDIUM_BROWN_ID = "33"
    DINO_DARK_BROWN_ID = "34"
    DINO_DARKER_GREY_ID = "35"
    DINO_ALBINO_ID = "36"
    BIGFOOT0_ID = "37"
    BIGFOOT4_ID = "38"
    BIGFOOT5_ID = "39"
    WOLFFUR_ID = "40"
    DARKWOLFFUR_ID = "41"
    DRAGONBASE0_ID = "42"
    DRAGONBASE1_ID = "43"
    DRAGONFIRE_ID = "44"
    DRAGONGREEN0_ID = "45"
    DRAGONGREEN1_ID = "46"
    DRAGONGREEN2_ID = "47"
    DRAGONGREEN3_ID = "48"
    WYVERNPURPLE0_ID = "49"
    WYVERNPURPLE1_ID = "50"
    WYVERNBLUE0_ID = "51"
    WYVERNBLUE1_ID = "52"
    DINO_MEDIUM_BLUE_ID = "53"
    DINO_DEEP_BLUE_ID = "54"
    NEARWHITE_ID = "55"
    NEARBLACK_ID = "56"
    DARKTURQUOISE_ID = "57"
    MEDIUMTURQUOISE_ID = "58"
    TURQUOISE_ID = "59"
    GREENSLATE_ID = "60"
    SAGE_ID = "61"
    DARKWARMGRAY_ID = "62"
    MEDIUMWARMGRAY_ID = "63"
    LIGHTWARMGRAY_ID = "64"
    DARKCEMENT_ID = "65"
    LIGHTCEMENT_ID = "66"
    LIGHTPINK_ID = "67"
    DEEPPINK_ID = "68"
    DARKVIOLET_ID = "69"
    DARKMAGENTA_ID = "70"
    BURNTSIENNA_ID = "71"
    MEDIUMAUTUMN_ID = "72"
    VERMILLION_ID = "73"
    CORAL_ID = "74"
    ORANGE_ID = "75"
    PEACH_ID = "76"
    LIGHTAUTUMN_ID = "77"
    MUSTARD_ID = "78"
    ACTUALBLACK_ID = "79"
    MIDNIGHTBLUE_ID = "80"
    DARKBLUE_ID = "81"
    BLACKSANDS_ID = "82"
    LEMONLIME_ID = "83"
    MINT_ID = "84"
    JADE_ID = "85"
    PINEGREEN_ID = "86"
    SPRUCEGREEN_ID = "87"
    LEAFGREEN_ID = "88"
    DARKLAVENDER_ID = "89"
    MEDIUMLAVENDER_ID = "90"
    LAVENDER_ID = "91"
    DARKTEAL_ID = "92"
    MEDIUMTEAL_ID = "93"
    TEAL_ID = "94"
    POWDERBLUE_ID = "95"
    GLACIAL_ID = "96"
    CAMMO_ID = "97"
    DRYMOSS_ID = "98"
    CUSTARD_ID = "99"
    CREAM_ID = "100"

class ColorHex:
    RED_HEX = "ff0000"
    BLUE_HEX = "0000ff"
    GREEN_HEX = "00ff00"
    YELLOW_HEX = "ffff00"
    CYAN_HEX = "00ffff"
    MAGENTA_HEX = "ff00ff"
    LIGHT_GREEN_HEX = "c0ffba"
    LIGHT_GREY_HEX = "c8caca"
    LIGHT_BROWN_HEX = "786759"
    LIGHT_ORANGE_HEX = "ffb46c"
    LIGHT_YELLOW_HEX = "fffa8a"
    LIGHT_RED_HEX = "ff756c"
    DARK_GREY_HEX = "7b7b7b"
    BLACK_HEX = "3b3b3b"
    BROWN_HEX = "593a2a"
    DARK_GREEN_HEX = "224900"
    DARK_RED_HEX = "812118"
    WHITE_HEX = "ffffff"
    DINO_LIGHT_RED_HEX = "ffa8a8"
    DINO_DARK_RED_HEX = "592b2b"
    DINO_LIGHT_ORANGE_HEX = "ffb694"
    DINO_DARK_ORANGE_HEX = "88532f"
    DINO_LIGHT_YELLOW_HEX = "cacaa0"
    DINO_DARK_YELLOW_HEX = "94946c"
    DINO_LIGHT_GREEN_HEX = "e0ffe0"
    DINO_MEDIUM_GREEN_HEX = "799479"
    DINO_DARK_GREEN_HEX = "224122"
    DINO_LIGHT_BLUE_HEX = "d9e0ff"
    DINO_DARK_BLUE_HEX = "394263"
    DINO_LIGHT_PURPLE_HEX = "e4d9ff"
    DINO_DARK_PURPLE_HEX = "403459"
    DINO_LIGHT_BROWN_HEX = "ffe0ba"
    DINO_MEDIUM_BROWN_HEX = "948575"
    DINO_DARK_BROWN_HEX = "594e41"
    DINO_DARKER_GREY_HEX = "595959"
    DINO_ALBINO_HEX = "ffffff"
    BIGFOOT0_HEX = "b79683"
    BIGFOOT4_HEX = "eadad5"
    BIGFOOT5_HEX = "d0a794"
    WOLFFUR_HEX = "c3b39f"
    DARKWOLFFUR_HEX = "887666"
    DRAGONBASE0_HEX = "a0664b"
    DRAGONBASE1_HEX = "cb7956"
    DRAGONFIRE_HEX = "bc4f00"
    DRAGONGREEN0_HEX = "79846c"
    DRAGONGREEN1_HEX = "909c79"
    DRAGONGREEN2_HEX = "a5a48b"
    DRAGONGREEN3_HEX = "74939c"
    WYVERNPURPLE0_HEX = "787496"
    WYVERNPURPLE1_HEX = "b0a2c0"
    WYVERNBLUE0_HEX = "6281a"
    WYVERNBLUE1_HEX = "485c75"
    DINO_MEDIUM_BLUE_HEX = "5fa4ea"
    DINO_DEEP_BLUE_HEX = "4568d4"
    NEARWHITE_HEX = "ededed"
    NEARBLACK_HEX = "515151"
    DARKTURQUOISE_HEX = "184546"
    MEDIUMTURQUOISE_HEX = "007060"
    TURQUOISE_HEX = "00c5ab"
    GREENSLATE_HEX = "40594c"
    SAGE_HEX = "3e4f40"
    DARKWARMGRAY_HEX = "3b3938"
    MEDIUMWARMGRAY_HEX = "585554"
    LIGHTWARMGRAY_HEX = "9b9290"
    DARKCEMENT_HEX = "525b56"
    LIGHTCEMENT_HEX = "8aa196"
    LIGHTPINK_HEX = "e8b0ff"
    DEEPPINK_HEX = "ff119a"
    DARKVIOLET_HEX = "730046"
    DARKMAGENTA_HEX = "b70042"
    BURNTSIENNA_HEX = "7e331e"
    MEDIUMAUTUMN_HEX = "a93000"
    VERMILLION_HEX = "ef3100"
    CORAL_HEX = "ff5834"
    ORANGE_HEX = "ff7f00"
    PEACH_HEX = "ffa73a"
    LIGHTAUTUMN_HEX = "ae7000"
    MUSTARD_HEX = "949427"
    ACTUALBLACK_HEX = "171717"
    MIDNIGHTBLUE_HEX = "191d36"
    DARKBLUE_HEX = "152b3a"
    BLACKSANDS_HEX = "302531"
    LEMONLIME_HEX = "a8ff44"
    MINT_HEX = "38e985"
    JADE_HEX = "008840"
    PINEGREEN_HEX = "0f552e"
    SPRUCEGREEN_HEX = "005b45"
    LEAFGREEN_HEX = "5b9725"
    DARKLAVENDER_HEX = "5e275f"
    MEDIUMLAVENDER_HEX = "853587"
    LAVENDER_HEX = "bd77be"
    DARKTEAL_HEX = "0e404a"
    MEDIUMTEAL_HEX = "105563"
    TEAL_HEX = "14849c"
    POWDERBLUE_HEX = "82a7ff"
    GLACIAL_HEX = "aceaff"
    CAMMO_HEX = "505118"
    DRYMOSS_HEX = "766e3f"
    CUSTARD_HEX = "c0bd5e"
    CREAM_HEX = "f4ffc0"


class DyeID:
    BLACK_DYE_ID = "201"
    BLUE_DYE_ID = "202"
    BROWN_DYE_ID = "203"
    CYAN_DYE_ID = "204"
    FOREST_DYE_ID = "205"
    GREEN_DYE_ID = "206"
    UNCRAFTABLE_PURPLE_DYE_ID = "207"
    ORANGE_DYE_ID = "208"
    PARCHMENT_DYE_ID = "209"
    PINK_DYE_ID = "210"
    PURPLE_DYE_ID = "211"
    RED_DYE_ID = "212"
    ROYALTY_DYE_ID = "213"
    SILVER_DYE_ID = "214"
    SKY_DYE_ID = "215"
    TAN_DYE_ID = "216"
    TANGERINE_DYE_ID = "217"
    WHITE_DYE_ID = "218"
    YELLOW_DYE_ID = "219"
    MAGENTA_DYE_ID = "220"
    BRICK_DYE_ID = "221"
    CANTALOUPE_DYE_ID = "222"
    MUD_DYE_ID = "223"
    NAVY_DYE_ID = "224"
    OLIVE_DYE_ID = "225"
    SLATE_DYE_ID = "226"


class DyeHex:
    BLACK_DYE_HEX = "1f1f1f"
    BLUE_DYE_HEX = "0000ff"
    BROWN_DYE_HEX = "756147"
    CYAN_DYE_HEX = "00ffff"
    FOREST_DYE_HEX = "006c00"
    GREEN_DYE_HEX = "00ff00"
    UNCRAFTABLE_PURPLE_DYE_HEX = "6c00ba"
    ORANGE_DYE_HEX = "ff8800"
    PARCHMENT_DYE_HEX = "ffffba"
    PINK_DYE_HEX = "ff7be1"
    PURPLE_DYE_HEX = "7b00e0"
    RED_DYE_HEX = "ff0000"
    ROYALTY_DYE_HEX = "7b00a8"
    SILVER_DYE_HEX = "e0e0e0"
    SKY_DYE_HEX = "bad4ff"
    TAN_DYE_HEX = "ffed82"
    TANGERINE_DYE_HEX = "ad652c"
    WHITE_DYE_HEX = "fefefe"
    YELLOW_DYE_HEX = "ffff00"
    MAGENTA_DYE_HEX = "e71fd9"
    BRICK_DYE_HEX = "94341f"
    CANTALOUPE_DYE_HEX = "ff9a00"
    MUD_DYE_HEX = "473b2b"
    NAVY_DYE_HEX = "34346c"
    OLIVE_DYE_HEX = "baba59"
    SLATE_DYE_HEX = "595959"



import pickle
from arklibrary.admin import Admin, Bundle
from arklibrary.lib.configuration import Ini

required_types = [int, float, set, bool, type(None), str, dict, list, Admin, Bundle, Ini]


def assert_data_types(data):
    type_names = ', '.join([data_type.__name__ for data_type in required_types])
    message = f"\nEncoding must be of types: {type_names}\nBut was: {type(data).__name__}"
    assert any([isinstance(data, data_type) for data_type in required_types]), message


def encode(data) -> bytes:
    assert_data_types(data)
    return pickle.dumps(data)


def decode(stream):
    return pickle.loads(stream)




from arklibrary.blueprints.beacons import *
from arklibrary.blueprints.commands import *
from arklibrary.blueprints.creatures import Alphas, Dinos, Bosses, Event, set_creatures_admin
from arklibrary.blueprints.colors import *
from arklibrary.blueprints.ammunitions import Ammunition
from arklibrary.blueprints.armours import Armour
from arklibrary.blueprints.artifacts import Artifacts
from arklibrary.blueprints.chibis import Chibis
from arklibrary.blueprints.consumables import Consumables
from arklibrary.blueprints.dyes import Dyes
from arklibrary.blueprints.eggs import Eggs
from arklibrary.blueprints.farming import Farming
from arklibrary.blueprints.recipes import Recipes
from arklibrary.blueprints.resources import Resources
from arklibrary.blueprints.saddles import Saddles
from arklibrary.blueprints.seeds import Seeds
from arklibrary.blueprints.skins import Skins
from arklibrary.blueprints.structures import Structures
from arklibrary.blueprints.tools import Tools
from arklibrary.blueprints.trophies import Trophies
from arklibrary.blueprints.weapons import Weapons



from pathlib import Path
import json


class Config:
    __config = None

    @classmethod
    def get(cls):
        if cls.__config:
            return cls.__config
        path = Path.cwd() / Path("config.json")
        assert path.exists(), "Unable to find the config file."
        with open(path, 'r') as r:
            cls.__config = json.load(r)

    @classmethod
    def admin_password(cls):
        return cls.get()['admin_password']

    @classmethod
    def ark_lnk_path(cls):
        return cls.get()['ark_lnk_path']

    @classmethod
    def admin_player_id(cls):
        return cls.get()['admin_player_id']

    def __repr__(self):
        items = []
        for k, v in self.__dict__.items():
            if k and k[0] != "_":
                items.append(f"\033[34m{k}\033[90m=\033[0m{repr(v)}\033[0m")
        args = ', '.join(items)
        return f'<\033[96m{type(self).__name__}\033[0m({args})>\033[0m'


import xmltodict
import requests
import os
import socket

IP = socket.gethostbyname(socket.gethostname())
namecheap_key = os.getenv('NAMECHEAP_KEY')
namecheap_username = os.getenv('NAMECHEAP_USERNAME')
URL = f"https://api.namecheap.com/xml.response?ApiUser={namecheap_username}&ApiKey={namecheap_key}&UserName={namecheap_username}&ClientIp={IP}"


def __filter_result(data: dict):
    return {key.replace("@", "").lower(): value for key, value in data.items()}


def get_list() -> dict:
    path = URL + f"&Command=namecheap.domains.getList"
    response = requests.get(path)
    data = xmltodict.parse(response.text)
    api_response = data['ApiResponse']
    if api_response['@Status'] != 'OK':
        raise Exception(f"{api_response['Errors']}")
    command_response = api_response['CommandResponse']
    list_result = command_response['DomainGetListResult']
    return [__filter_result(item) for item in list_result['Domain']]


def get_info(domain: str) -> dict:
    path = URL + f"&Command=namecheap.domains.getinfo&DomainName={domain}"
    response = requests.get(path)
    data = xmltodict.parse(response.text)
    api_response = data['ApiResponse']
    if api_response['@Status'] != 'OK':
        raise Exception(f"{api_response['Errors']}")
    command_response = api_response['CommandResponse']
    info_result = command_response['DomainGetInfoResult']
    return __filter_result(info_result)


class Host:
    __ID = 1
    def __init__(self, record_type=None, address=None, host_name=None, ttl=None):
        assert record_type in ["A",         # A Record
                               "AAAA",      # AAAA Record
                               "ALIAS",     # ALIAS Record
                               "CAA",       # CAA Record
                               "CNAME",     # CNAME Record
                               "MX",        # Masked? Record
                               "MXE",       # Masked? Record
                               "NS",        # NS Record
                               "TXT",       # TXT Record
                               "URL",       # URL Redirect Record
                               "URL301",    # Permanent URL Redirect Record
                               "FRAME"]
        assert host_name in ['@', 'www']
        self.id = Host.__ID
        Host.__ID += 1
        self.record_type = record_type
        self.address = address
        self.host_name = host_name
        self.ttl = ttl

    def __str__(self):
        path = f"&HostName{self.id}={self.host_name}"
        path += f"&RecordType{self.id}={self.record_type}"
        path += f"&Address{self.id}={self.address}"
        path += f"&TTL{self.id}={self.ttl}" if self.ttl else ''
        return path


def set_hosts(*args: Host, SLD='', TLD='') -> dict:
    names = [item['name'] for item in get_list()]
    assert f"{SLD}.{TLD}" in names, f"{SLD}.{TLD} is not in: {names}"

    path = URL
    path += f"&Command=namecheap.domains.dns.setHosts"
    path += f"&SLD={SLD}&TLD={TLD}"
    for host in args:
        path += f"{host}"

    response = requests.get(path)
    data = xmltodict.parse(response.text)
    api_response = data['ApiResponse']
    if api_response['@Status'] != 'OK':
        raise Exception(f"{api_response['Errors']}")
    command_response = api_response['CommandResponse']
    set_hosts_result = command_response['DomainDNSSetHostsResult']
    return __filter_result(set_hosts_result)


if __name__ == "__main__":
    host1 = Host(record_type='URL', host_name='@', address='http://ark-api.guru')
    host2 = Host(record_type='URL', host_name='www', address='http://ark-api.guru')
    response = set_hosts(host1, host2, SLD='ark-shop', TLD='guru')
    print(response)




class Saddles:
    ALLOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_AlloSaddle.PrimalItemArmor_AlloSaddle'"
    ANKYLO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_AnkyloSaddle.PrimalItemArmor_AnkyloSaddle'"
    ARANEO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SpiderSaddle.PrimalItemArmor_SpiderSaddle'"
    ARGENTAVIS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ArgentavisSaddle.PrimalItemArmor_ArgentavisSaddle'"
    ARTHROPLUERA_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ArthroSaddle.PrimalItemArmor_ArthroSaddle'"
    ASTROCETUS_TEK_SADDLE = "Blueprint'/Game/Genesis/Dinos/SpaceWhale/PrimalItemArmor_SpaceWhaleSaddle_Tek.PrimalItemArmor_SpaceWhaleSaddle_Tek'"
    BARYONYX_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_BaryonyxSaddle.PrimalItemArmor_BaryonyxSaddle'"
    BASILISK_SADDLE = "Blueprint'/Game/Aberration/Dinos/Basilisk/PrimalItemArmor_BasiliskSaddle.PrimalItemArmor_BasiliskSaddle'"
    BASILOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_BasiloSaddle.PrimalItemArmor_BasiloSaddle'"
    BEELZEBUFO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ToadSaddle.PrimalItemArmor_ToadSaddle'"
    BRONTO_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SauroSaddle_Platform.PrimalItemArmor_SauroSaddle_Platform'"
    BRONTO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SauroSaddle.PrimalItemArmor_SauroSaddle'"
    CARBONEMYS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TurtleSaddle.PrimalItemArmor_TurtleSaddle'"
    CARNO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_CarnoSaddle.PrimalItemArmor_CarnoSaddle'"
    CASTOROIDES_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_BeaverSaddle.PrimalItemArmor_BeaverSaddle'"
    CHALICOTHERIUM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ChalicoSaddle.PrimalItemArmor_ChalicoSaddle'"
    DAEODON_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DaeodonSaddle.PrimalItemArmor_DaeodonSaddle'"
    DEINONYCHUS_SADDLE = "Blueprint'/Game/Valguero/Dinos/Deinonychus/PrimalItemArmor_DeinonychusSaddle.PrimalItemArmor_DeinonychusSaddle'"
    DIPLODOCUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DiplodocusSaddle.PrimalItemArmor_DiplodocusSaddle'"
    DIREBEAR_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DireBearSaddle.PrimalItemArmor_DireBearSaddle'"
    DOEDICURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DoedSaddle.PrimalItemArmor_DoedSaddle'"
    DUNKLEOSTEUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DunkleosteusSaddle.PrimalItemArmor_DunkleosteusSaddle'"
    EQUUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_EquusSaddle.PrimalItemArmor_EquusSaddle'"
    GACHA_SADDLE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Saddle/PrimalItemArmor_GachaSaddle.PrimalItemArmor_GachaSaddle'"
    GALLIMIMUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_Gallimimus.PrimalItemArmor_Gallimimus'"
    GASBAGS_SADDLE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Saddle/PrimalItemArmor_GasBagsSaddle.PrimalItemArmor_GasBagsSaddle'"
    GIGANOTOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_GigantSaddle.PrimalItemArmor_GigantSaddle'"
    HYAENODON_MEATPACK = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_HyaenodonSaddle.PrimalItemArmor_HyaenodonSaddle'"
    ICHTHYOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_DolphinSaddle.PrimalItemArmor_DolphinSaddle'"
    IGUANODON_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_IguanodonSaddle.PrimalItemArmor_IguanodonSaddle'"
    KAPROSUCHUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_KaprosuchusSaddle.PrimalItemArmor_KaprosuchusSaddle'"
    KARKINOS_SADDLE = "Blueprint'/Game/Aberration/Dinos/Crab/PrimalItemArmor_CrabSaddle.PrimalItemArmor_CrabSaddle'"
    LYMANTRIA_SADDLE = "Blueprint'/Game/ScorchedEarth/Dinos/Moth/PrimalItemArmor_MothSaddle.PrimalItemArmor_MothSaddle'"
    MAGMASAUR_SADDLE = "Blueprint'/Game/Genesis/Dinos/Cherufe/PrimalItemArmor_CherufeSaddle.PrimalItemArmor_CherufeSaddle'"
    MAMMOTH_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MammothSaddle.PrimalItemArmor_MammothSaddle'"
    MANAGARMR_SADDLE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Saddle/PrimalItemArmor_IceJumperSaddle.PrimalItemArmor_IceJumperSaddle'"
    MANTA_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MantaSaddle.PrimalItemArmor_MantaSaddle'"
    MANTIS_SADDLE = "Blueprint'/Game/ScorchedEarth/Dinos/Mantis/PrimalItemArmor_MantisSaddle.PrimalItemArmor_MantisSaddle'"
    MEGACHELON_PLATFORM_SADDLE = "Blueprint'/Game/Genesis/Dinos/GiantTurtle/PrimalItemArmor_GiantTurtleSaddle.PrimalItemArmor_GiantTurtleSaddle'"
    MEGALOCEROS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_StagSaddle.PrimalItemArmor_StagSaddle'"
    MEGALODON_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MegalodonSaddle.PrimalItemArmor_MegalodonSaddle'"
    MEGALOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MegalosaurusSaddle.PrimalItemArmor_MegalosaurusSaddle'"
    MEGALANIA_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MegalaniaSaddle.PrimalItemArmor_MegalaniaSaddle'"
    MEGALODON_TEK_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MegalodonSaddle_Tek.PrimalItemArmor_MegalodonSaddle_Tek'"
    MEGATHERIUM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MegatheriumSaddle.PrimalItemArmor_MegatheriumSaddle'"
    MORELLATOPS_SADDLE = "Blueprint'/Game/ScorchedEarth/Dinos/Camelsaurus/PrimalItemArmor_CamelsaurusSaddle.PrimalItemArmor_CamelsaurusSaddle'"
    MOSASAUR_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MosaSaddle_Platform.PrimalItemArmor_MosaSaddle_Platform'"
    MOSASAUR_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MosaSaddle.PrimalItemArmor_MosaSaddle'"
    MOSASAUR_TEK_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_MosaSaddle_Tek.PrimalItemArmor_MosaSaddle_Tek'"
    PACHY_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PachySaddle.PrimalItemArmor_PachySaddle'"
    PACHYRHINOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PachyrhinoSaddle.PrimalItemArmor_PachyrhinoSaddle'"
    PARACER_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ParacerSaddle_Platform.PrimalItemArmor_ParacerSaddle_Platform'"
    PARACER_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_Paracer_Saddle.PrimalItemArmor_Paracer_Saddle'"
    PARASAUR_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ParaSaddle.PrimalItemArmor_ParaSaddle'"
    PELAGORNIS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PelaSaddle.PrimalItemArmor_PelaSaddle'"
    PHIOMIA_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PhiomiaSaddle.PrimalItemArmor_PhiomiaSaddle'"
    PLESIOSAUR_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PlesiSaddle_Platform.PrimalItemArmor_PlesiSaddle_Platform'"
    PLESIOSAUR_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PlesiaSaddle.PrimalItemArmor_PlesiaSaddle'"
    PROCOPTODON_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ProcoptodonSaddle.PrimalItemArmor_ProcoptodonSaddle'"
    PTERANODON_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_PteroSaddle.PrimalItemArmor_PteroSaddle'"
    PULMONOSCORPIUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ScorpionSaddle.PrimalItemArmor_ScorpionSaddle'"
    QUETZ_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_QuetzSaddle_Platform.PrimalItemArmor_QuetzSaddle_Platform'"
    QUETZ_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_QuetzSaddle.PrimalItemArmor_QuetzSaddle'"
    RAPTOR_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_RaptorSaddle.PrimalItemArmor_RaptorSaddle'"
    RAVAGER_SADDLE = "Blueprint'/Game/Aberration/Dinos/CaveWolf/PrimalItemArmor_CavewolfSaddle.PrimalItemArmor_CavewolfSaddle'"
    REX_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_RexSaddle.PrimalItemArmor_RexSaddle'"
    REX_TEK_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_RexSaddle_Tek.PrimalItemArmor_RexSaddle_Tek'"
    ROCK_DRAKE_SADDLE = "Blueprint'/Game/Aberration/Dinos/RockDrake/PrimalItemArmor_RockDrakeSaddle.PrimalItemArmor_RockDrakeSaddle'"
    ROCK_DRAKE_TEK_SADDLE = "Blueprint'/Game/Aberration/Dinos/RockDrake/PrimalItemArmor_RockDrakeSaddle_Tek.PrimalItemArmor_RockDrakeSaddle_Tek'"
    ROCK_GOLEM_SADDLE = "Blueprint'/Game/ScorchedEarth/Dinos/RockGolem/PrimalItemArmor_RockGolemSaddle.PrimalItemArmor_RockGolemSaddle'"
    ROLL_RAT_SADDLE = "Blueprint'/Game/Aberration/Dinos/MoleRat/PrimalItemArmor_MoleRatSaddle.PrimalItemArmor_MoleRatSaddle'"
    SABERTOOTH_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SaberSaddle.PrimalItemArmor_SaberSaddle'"
    SARCO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SarcoSaddle.PrimalItemArmor_SarcoSaddle'"
    SNOW_OWL_SADDLE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Saddle/PrimalItemArmor_OwlSaddle.PrimalItemArmor_OwlSaddle'"
    SPINO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_SpinoSaddle.PrimalItemArmor_SpinoSaddle'"
    STEGO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_StegoSaddle.PrimalItemArmor_StegoSaddle'"
    TAPEJARA_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TapejaraSaddle.PrimalItemArmor_TapejaraSaddle'"
    TAPEJARA_TEK_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_Tapejara_Tek.PrimalItemArmor_Tapejara_Tek'"
    TERROR_BIRD_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TerrorBirdSaddle.PrimalItemArmor_TerrorBirdSaddle'"
    THERIZINOSAURUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TherizinosaurusSaddle.PrimalItemArmor_TherizinosaurusSaddle'"
    THORNY_DRAGON_SADDLE = "Blueprint'/Game/ScorchedEarth/Dinos/SpineyLizard/PrimalItemArmor_SpineyLizardSaddle.PrimalItemArmor_SpineyLizardSaddle'"
    THYLACOLEO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_ThylacoSaddle.PrimalItemArmor_ThylacoSaddle'"
    TITANOSAUR_PLATFORM_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TitanSaddle_Platform.PrimalItemArmor_TitanSaddle_Platform'"
    TRIKE_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TrikeSaddle.PrimalItemArmor_TrikeSaddle'"
    TROPEOGNATHUS_SADDLE = "Blueprint'/Game/PrimalEarth/Dinos/Tropeognathus/PrimalItemArmor_TropeSaddle.PrimalItemArmor_TropeSaddle'"
    TUSOTEUTHIS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_TusoSaddle.PrimalItemArmor_TusoSaddle'"
    VELONASAUR_SADDLE = "Blueprint'/Game/Extinction/CoreBlueprints/Items/Saddle/PrimalItemArmor_SpindlesSaddle.PrimalItemArmor_SpindlesSaddle'"
    WOOLLY_RHINO_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_RhinoSaddle.PrimalItemArmor_RhinoSaddle'"
    YUTYRANNUS_SADDLE = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/Armor/Saddles/PrimalItemArmor_YutySaddle.PrimalItemArmor_YutySaddle'"


from bs4 import BeautifulSoup
from pathlib import Path
import requests
import json
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.remote.webelement import WebElement
from time import sleep


items_id_webpage = "https://ark.fandom.com/wiki/Item_IDs"
creatures_id_webpage = "https://ark.fandom.com/wiki/Creature_IDs"

def get_driver():
    d = webdriver.Chrome(executable_path=r"C:\Users\optimus\OneDrive\Developer\.id\.drivers\chrome\windows\94.0.4606.61\chromedriver.exe")
    return d



def click_show(driver: webdriver.Chrome):
    driver.get(items_id_webpage)
    driver.refresh()
    sleep(3)
    spans = driver.find_elements_by_tag_name('span')
    show_spans = []
    for span in spans:
        if span.text.lower() == 'show':
            show_spans.append(span)
    for show in show_spans:
        show.click()
        sleep(0.3)


def get_table_elements(driver: webdriver.Chrome):
    loaded = driver.find_elements_by_tag_name('table')
    tables = []
    for t in loaded:
        tables.append(t.find_elements_by_tag_name('tr'))
    return tables


def extract_data_from_table(table: list[WebElement]):
    header_list = table[0].find_elements_by_tag_name('th')
    headers = ['_'.join(h.text.lower().replace("-", "_").split()) for h in header_list]
    print(headers)
    data = []
    for element in table[1:]:
        row_elements = element.find_elements_by_tag_name('td')
        assert len(row_elements) == len(headers)
        data.append(dict(zip(headers, row_elements)))
    return data


def clean_data(data: list[dict]):
    cleaned = []
    for row in data:
        row_data = {}
        for col_name, element in row.items():
            if col_name == 'name':
                row_data[col_name] = element.text
                row_data['url'] = None
                for e in element.find_elements_by_tag_name('a'):
                    if e.text != '':
                        row_data['url'] = e.get_property('href')
            else:
                text = element.text
                row_data[col_name] = None if text == '-' or text == '' else text
        cleaned.append(row_data)
    return cleaned


if __name__ == "__main__":
    driver = get_driver()
    sleep(5)
    driver.get(items_id_webpage)
    sleep(5)
    click_show(driver)
    table_elements = get_table_elements(driver)
    extracted = []
    for te in table_elements:
        try:
            extracted.append(extract_data_from_table(te))
        except:
            pass

    data = []
    for ext in extracted:
        data.append(clean_data(ext))

    for i, d in enumerate(data):
        with open(f"tools/data/items/{i}.json", 'w') as w:
            json.dump(d, w)

    driver.quit()



import json
from arklibrary.data_structures.encoder import encode, decode
from collections import defaultdict
import pickle


class Stream:
    r"""
    A header is a 1 of the 3 parts which make up the Stream:
        Stream = [Size Stream][Header Stream][Data Stream]
                - Size Stream: length of the header stream.
                - Header Stream: extra data about the body, credentials, etc.
                - Data Stream: the raw data being sent.
        Ex.
                         Size       Header Stream                               Data Stream
            Stream   =   0036   |   {body_length: 19, body_type: 'json'}   |    {'data': 'my data'}
            Stream   =   0038   |   {body_length: 19, body_type: 'pickle'} |    \x8\a43\x92\x213\x1
            Stream   =   0035   |   {body_length: 19, body_type: 'str'}   |     this is my data str
    """
    SIZE = 4  # is 4 decimal digits long (e.g. 4 bytes)

    @classmethod
    def new(cls, stream: bytes) -> 'Stream':
        return pickle.loads(stream)

    def __init__(self, **kwargs):
        attrs = defaultdict(lambda: None)
        attrs.update(kwargs)
        self.from_address = attrs['from_address']
        self.to_address = attrs['to_address']
        self.authentication = attrs['authentication']
        self.expiration = attrs['expiration']
        self.body = attrs['body']
        self.function = attrs['function']
        self.type = attrs['type']

    def keys(self):
        return self.__dict__.keys()

    def items(self):
        return self.__dict__.items()

    def __getitem__(self, item):
        return self.__dict__[item]

    def encode(self) -> bytes:
        return pickle.dumps(self)

    def __getstate__(self):
        state = self.__dict__.copy()
        state['body'] = encode(self.body)
        return state

    def __setstate__(self, state):
        self.__dict__.update(state)
        self.body = decode(state['body'])

    def __eq__(self, other):
        return other.__dict__ == self.__dict__

    def __repr__(self):
        items = []
        for k, v in dict(self).items():
            items.append(f"\033[34m{k}\033[90m=\033[0m{repr(v)}\033[0m")
        args = ', '.join(items)
        return f'<\033[96mHeader\033[0m({args})>\033[0m'




from arklibrary.blueprints import Weapons, Structures, Tools, Resources
from arklibrary.blueprints import Armour, Dinos, Saddles, Ammunition
from arklibrary.admin import Admin
import math


class Bundle:
    def __init__(self, admin: Admin):
        self.admin = admin

    def execute(self):
        self.admin.execute()

    def flak_armour(self, player_id, quality=0):
        boots = Armour.FLAK_BOOTS
        leggings = Armour.FLAK_LEGGINGS
        chest = Armour.FLAK_CHESTPIECE
        gauntlets = Armour.FLAK_GAUNTLETS
        helmet = Armour.FLAK_HELMET
        wings = Armour.GLIDER_SUIT
        self.admin.give_items_to_player(player_id, [boots, leggings, chest, gauntlets, helmet, wings], quality=quality)

    def hazard_armour(self, player_id, quality=0):
        boots = Armour.HAZARD_SUIT_BOOTS
        leggings = Armour.HAZARD_SUIT_PANTS
        chest = Armour.HAZARD_SUIT_SHIRT
        gauntlets = Armour.HAZARD_SUIT_GLOVES
        helmet = Armour.HAZARD_SUIT_HAT
        wings = Armour.GLIDER_SUIT
        self.admin.give_items_to_player(player_id, [boots, leggings, chest, gauntlets, helmet, wings], quality=quality)

    def desert_armour(self, player_id, quality=0):
        boots = Armour.DESERT_CLOTH_BOOTS
        leggings = Armour.DESERT_CLOTH_PANTS
        chest = Armour.DESERT_CLOTH_SHIRT
        gauntlets = Armour.DESERT_CLOTH_GLOVES
        helmet = Armour.DESERT_GOGGLES_AND_HAT
        wings = Armour.GLIDER_SUIT
        self.admin.give_items_to_player(player_id, [boots, leggings, chest, gauntlets, helmet, wings], quality=quality)

    def fur_armour(self, player_id, quality=0):
        boots = Armour.FUR_BOOTS
        leggings = Armour.FUR_LEGGINGS
        chest = Armour.FUR_CHESTPIECE
        gauntlets = Armour.FUR_GAUNTLETS
        helmet = Armour.FUR_CAP
        wings = Armour.GLIDER_SUIT
        self.admin.give_items_to_player(player_id, [boots, leggings, chest, gauntlets, helmet, wings], quality=quality)

    def tek_armour(self, player_id, quality=0):
        boots = Armour.TEK_BOOTS
        leggings = Armour.TEK_LEGGINGS
        chest = Armour.TEK_CHESTPIECE
        gauntlets = Armour.TEK_GAUNTLETS
        helmet = Armour.TEK_HELMET
        self.admin.give_items_to_player(player_id, [boots, leggings, chest, gauntlets, helmet], quality=quality)

    def dino_starter(self, player_id, level=150):
        self.admin.teleport_to_playerid(player_id)
        self.admin.spawn_exact_dino(Dinos.PTERANODON, base_level=level)
        self.admin.give_items_to_player(player_id, Saddles.PTERANODON_SADDLE)

    def rocket_set(self, player_id):
        rockets = Ammunition.ROCKET_PROPELLED_GRENADE
        launcher = Weapons.ROCKET_LAUNCHER
        self.admin.give_items_to_player(player_id, [rockets], quantity=10)
        self.admin.give_items_to_player(player_id, [launcher])

    def shotgun_set(self, player_id, quality=0):
        shotgun = Weapons.PUMP_ACTION_SHOTGUN
        ammo = Ammunition.SIMPLE_SHOTGUN_AMMO
        self.admin.give_items_to_player(player_id, [ammo], quantity=100)
        self.admin.give_items_to_player(player_id, [shotgun], quality=quality)

    def soaker_set(self, player_id, level=150, quality=0):
        self.admin.teleport_to_playerid(player_id)
        self.admin.spawn_exact_dino(Dinos.TEK_STEGOSAURUS, base_level=level)
        self.admin.give_items_to_player(player_id, Saddles.STEGO_SADDLE, quality=quality)

    def sniper_set(self, player_id, quality=0):
        sniper = Weapons.FABRICATED_SNIPER_RIFLE
        ammo = Ammunition.ADVANCED_SNIPER_BULLET
        self.admin.give_items_to_player(player_id, [ammo], quantity=100)
        self.admin.give_items_to_player(player_id, [sniper], quality=quality)

    def compound_set(self, player_id, quality=0):
        bow = Weapons.COMPOUND_BOW
        ammo = Ammunition.METAL_ARROW
        flame = Ammunition.FLAME_ARROW
        self.admin.give_items_to_player(player_id, [ammo, flame], quantity=100)
        self.admin.give_items_to_player(player_id, [bow], quality=quality)

    def rifle_set(self, player_id, quality=0):
        rifle = Weapons.LONGNECK_RIFLE
        ammo = Ammunition.SIMPLE_RIFLE_AMMO
        tranq = Ammunition.SHOCKING_TRANQUILIZER_DART
        self.admin.give_items_to_player(player_id, [ammo, tranq], quantity=100)
        self.admin.give_items_to_player(player_id, [rifle], quality=quality)

    def hiking_set(self, player_id, quality=0):
        bow = Weapons.CROSSBOW
        grap = Ammunition.GRAPPLING_HOOK
        pick = Weapons.CLIMBING_PICK
        para = Armour.PARACHUTE
        glow = Weapons.GLOW_STICK
        self.admin.give_items_to_player(player_id, [pick], quantity=3)
        self.admin.give_items_to_player(player_id, [glow], quantity=5)
        self.admin.give_items_to_player(player_id, [grap, para], quantity=50)
        self.admin.give_items_to_player(player_id, [bow], quality=quality)

    def trap_set(self, player_id, quality=0):
        bow = Weapons.HARPOON_LAUNCHER
        net = Ammunition.NET_PROJECTILE
        trap = Weapons.BEAR_TRAP
        bear = Weapons.LARGE_BEAR_TRAP
        narc = Weapons.TRIPWIRE_NARCOTIC_TRAP
        bomb = Weapons.IMPROVISED_EXPLOSIVE_DEVICE
        self.admin.give_items_to_player(player_id, [trap, bear, narc, bomb], quantity=3)
        self.admin.give_items_to_player(player_id, [net], quantity=10)
        self.admin.give_items_to_player(player_id, [bow], quality=quality)

    def c4_set(self, player_id):
        detonator = Weapons.C4_REMOTE_DETONATOR
        ammo = Ammunition.C4_CHARGE
        self.admin.give_items_to_player(player_id, [ammo], quantity=20)
        self.admin.give_items_to_player(player_id, [detonator])

    def flame_arrow_set(self, player_id, quality=0):
        crossbow = Weapons.CROSSBOW
        ammo = Ammunition.FLAME_ARROW
        self.admin.give_items_to_player(player_id, [ammo], quantity=100)
        self.admin.give_items_to_player(player_id, [crossbow], quality=quality)

    def electrical_set(self, player_id, quantity=1):
        generator = Structures.ELECTRICAL_GENERATOR
        outlet = Structures.ELECTRICAL_OUTLET
        wires = [Structures.STRAIGHT_ELECTRICAL_CABLE,
                 Structures.VERTICAL_ELECTRICAL_CABLE,
                 Structures.ELECTRICAL_CABLE_INTERSECTION,
                 Structures.INCLINED_ELECTRICAL_CABLE]
        gas = Resources.GASOLINE
        self.admin.give_items_to_player(player_id, [gas] * quantity, quantity=50)
        self.admin.give_items_to_player(player_id, [generator], quantity=quantity)
        self.admin.give_items_to_player(player_id, wires + [outlet], quantity=quantity * 5)

    def crafting_set(self, player_id, quality=4, tek=False):
        smithy = Structures.SMITHY
        fabricator = Structures.FABRICATOR
        indiforge = Structures.INDUSTRIAL_FORGE
        chembench = Structures.CHEMISTRY_BENCH
        replicator = Structures.TEK_REPLICATOR
        gas = Resources.GASOLINE
        self.admin.give_items_to_player(player_id, [smithy, fabricator, indiforge, chembench][:quality])
        self.admin.give_item_to_player(player_id, gas, quantity=50)
        if tek:
            self.admin.give_items_to_player(player_id, replicator)

    def storage_set(self, player_id, quantity=1):
        wood = Structures.STORAGE_BOX
        vault = Structures.VAULT
        fridge = Structures.REFRIGERATOR
        cryofridge = Structures.CRYOFRIDGE
        self.admin.give_items_to_player(player_id, [wood, vault, fridge, cryofridge], quantity=quantity)

    def defense_set(self, player_id, quantity, quality=1):
        auto = Structures.AUTO_TURRET
        heavy = Structures.HEAVY_AUTO_TURRET
        ammo = Ammunition.ADVANCED_RIFLE_BULLET
        battery = Tools.BATTERY
        if quality == 1:
            self.admin.give_items_to_player(player_id, [heavy, battery], quantity=quantity)
        else:
            self.admin.give_items_to_player(player_id, [auto, battery], quantity=quantity)
        self.admin.give_items_to_player(player_id, [ammo], quantity=200)

    def base_set(self, player_id, quantity=10):
        foundation = Structures.METAL_FOUNDATION
        wall = Structures.METAL_WALL
        ceiling = Structures.METAL_CEILING
        pillar = Structures.METAL_PILLAR
        doors = [Structures.METAL_DOUBLE_DOORFRAME, Structures.METAL_DOUBLE_DOOR]
        self.admin.give_items_to_player(player_id, doors, quantity=math.ceil(quantity / 10))
        self.admin.give_items_to_player(player_id, [pillar, foundation, wall, ceiling], quantity=quantity)

    def fob_set(self, player_id, quantity=1):
        self.base_set(player_id, quantity=10 * quantity)
        self.electrical_set(player_id, quantity=quantity)
        self.defense_set(player_id, quantity=quantity * 3)
        self.admin.give_items_to_player(player_id, [Structures.GIANT_METAL_HATCHFRAME], quantity=quantity * 2)
        self.admin.give_items_to_player(player_id, [Structures.SIMPLE_BED], quantity=quantity * 4)
        self.admin.give_items_to_player(player_id, [Structures.VAULT], quantity=quantity)

    def resource_set(self, player_id, stacks=1, omit=[]):
        resources = [(Resources.METAL, 500),
                     (Resources.OBSIDIAN, 50),
                     (Resources.POLYMER, 50),
                     (Resources.HIDE, 300),
                     (Resources.OIL, 50),
                     (Resources.SILICA_PEARLS, 50),
                     (Resources.CHITIN, 100),
                     (Resources.STONE, 1000),
                     (Resources.FIBER, 1000),
                     (Resources.THATCH, 500),
                     (Resources.WOOD, 500),
                     (Resources.CRYSTAL, 50),
                     (Resources.FERTILIZER, 5),
                     (Resources.THATCH, 1000),
                     (Resources.FLINT, 1000),
                     (Resources.CHARCOAL, 500)]
        for resc in resources:
            blueprint, count = resc
            if blueprint not in omit:
                for i in range(stacks):
                    self.admin.give_item_to_player(player_id, blueprint, quantity=count)



class Dyes:
    BLACK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Black.PrimalItemDye_Black'"
    BLUE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Blue.PrimalItemDye_Blue'"
    BRICK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Brick.PrimalItemDye_Brick'"
    BROWN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Brown.PrimalItemDye_Brown'"
    CANTALOUPE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Cantaloupe.PrimalItemDye_Cantaloupe'"
    CYAN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Cyan.PrimalItemDye_Cyan'"
    FOREST_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Forest.PrimalItemDye_Forest'"
    GREEN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Green.PrimalItemDye_Green'"
    MAGENTA_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_ActuallyMagenta.PrimalItemDye_ActuallyMagenta'"
    MUD_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Mud.PrimalItemDye_Mud'"
    NAVY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Navy.PrimalItemDye_Navy'"
    OLIVE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Olive.PrimalItemDye_Olive'"
    ORANGE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Orange.PrimalItemDye_Orange'"
    PARCHMENT_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Parchment.PrimalItemDye_Parchment'"
    PINK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Pink.PrimalItemDye_Pink'"
    PURPLE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Purple.PrimalItemDye_Purple'"
    PURPLE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Magenta.PrimalItemDye_Magenta'"
    RED_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Red.PrimalItemDye_Red'"
    ROYALTY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Royalty.PrimalItemDye_Royalty'"
    SILVER_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Silver.PrimalItemDye_Silver'"
    SKY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Sky.PrimalItemDye_Sky'"
    SLATE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Slate.PrimalItemDye_Slate'"
    TAN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Tan.PrimalItemDye_Tan'"
    TANGERINE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Tangerine.PrimalItemDye_Tangerine'"
    WHITE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_White.PrimalItemDye_White'"
    YELLOW_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Yellow.PrimalItemDye_Yellow'"